# Generated by Django 5.0.1 on 2024-02-18 20:28

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("artd_order", "0001_initial"),
    ]

    operations = [
        migrations.AddField(
            model_name="order",
            name="external_id",
            field=models.CharField(
                blank=True,
                help_text="External ID of the object.",
                max_length=100,
                null=True,
                verbose_name="External ID",
            ),
        ),
        migrations.AddField(
            model_name="order",
            name="source",
            field=models.CharField(
                blank=True,
                help_text="Source of the object.",
                max_length=100,
                null=True,
                verbose_name="Source",
            ),
        ),
        migrations.AddField(
            model_name="orderadress",
            name="external_id",
            field=models.CharField(
                blank=True,
                help_text="External ID of the object.",
                max_length=100,
                null=True,
                verbose_name="External ID",
            ),
        ),
        migrations.AddField(
            model_name="orderadress",
            name="source",
            field=models.CharField(
                blank=True,
                help_text="Source of the object.",
                max_length=100,
                null=True,
                verbose_name="Source",
            ),
        ),
        migrations.AddField(
            model_name="orderdeliverymethod",
            name="external_id",
            field=models.CharField(
                blank=True,
                help_text="External ID of the object.",
                max_length=100,
                null=True,
                verbose_name="External ID",
            ),
        ),
        migrations.AddField(
            model_name="orderdeliverymethod",
            name="source",
            field=models.CharField(
                blank=True,
                help_text="Source of the object.",
                max_length=100,
                null=True,
                verbose_name="Source",
            ),
        ),
        migrations.AddField(
            model_name="orderpaymenthistory",
            name="external_id",
            field=models.CharField(
                blank=True,
                help_text="External ID of the object.",
                max_length=100,
                null=True,
                verbose_name="External ID",
            ),
        ),
        migrations.AddField(
            model_name="orderpaymenthistory",
            name="source",
            field=models.CharField(
                blank=True,
                help_text="Source of the object.",
                max_length=100,
                null=True,
                verbose_name="Source",
            ),
        ),
        migrations.AddField(
            model_name="orderproduct",
            name="external_id",
            field=models.CharField(
                blank=True,
                help_text="External ID of the object.",
                max_length=100,
                null=True,
                verbose_name="External ID",
            ),
        ),
        migrations.AddField(
            model_name="orderproduct",
            name="source",
            field=models.CharField(
                blank=True,
                help_text="Source of the object.",
                max_length=100,
                null=True,
                verbose_name="Source",
            ),
        ),
        migrations.AddField(
            model_name="orderstatus",
            name="external_id",
            field=models.CharField(
                blank=True,
                help_text="External ID of the object.",
                max_length=100,
                null=True,
                verbose_name="External ID",
            ),
        ),
        migrations.AddField(
            model_name="orderstatus",
            name="source",
            field=models.CharField(
                blank=True,
                help_text="Source of the object.",
                max_length=100,
                null=True,
                verbose_name="Source",
            ),
        ),
        migrations.AddField(
            model_name="orderstatushistory",
            name="external_id",
            field=models.CharField(
                blank=True,
                help_text="External ID of the object.",
                max_length=100,
                null=True,
                verbose_name="External ID",
            ),
        ),
        migrations.AddField(
            model_name="orderstatushistory",
            name="source",
            field=models.CharField(
                blank=True,
                help_text="Source of the object.",
                max_length=100,
                null=True,
                verbose_name="Source",
            ),
        ),
    ]



from django.contrib import admin
from artd_order.models import (
    OrderStatus,
    Order,
    OrderProduct,
    OrderStatusHistory,
    OrderPaymentHistory,
    OrderDeliveryMethod,
    OrderAdress,
)
from django_json_widget.widgets import JSONEditorWidget
from django.db import models
from django.utils.translation import gettext_lazy as _


class OrderProductInline(admin.StackedInline):
    model = OrderProduct
    extra = 1
    show_change_link = True
    fields = (
        "product",
        "quantity",
    )


class OrderAdressInline(admin.StackedInline):
    model = OrderAdress
    extra = 2
    show_change_link = True
    fields = (
        "address_type",
        "city",
        "phone",
        "address",
        "firstname",
        "lastname",
        "email",
    )


class OrderPaymentHistoryInline(admin.StackedInline):
    model = OrderPaymentHistory
    extra = 1
    show_change_link = True
    fields = ("payment_code",)


class OrderStatusHistoryInline(admin.StackedInline):
    model = OrderStatusHistory
    extra = 1
    show_change_link = True
    fields = (
        "order_status",
        "comment",
    )


@admin.register(OrderStatus)
class OrderStatusAdmin(admin.ModelAdmin):
    list_display = (
        "status_description",
        "id",
        "status_code",
        "status",
    )
    search_fields = (
        "id",
        "status_code",
        "status_description",
    )
    list_filter = ("status",)
    readonly_fields = (
        "id",
        "created_at",
        "updated_at",
    )
    fieldsets = [
        (
            _("Order status information"),
            {
                "fields": (
                    "status_code",
                    "status_description",
                )
            },
        ),
        (
            _("Status Information"),
            {
                "fields": ("status",),
            },
        ),
        (
            _("Source Information"),
            {
                "fields": (
                    "external_id",
                    "source",
                    "json_data",
                ),
            },
        ),
        (
            _("Timestamps"),
            {
                "fields": (
                    "created_at",
                    "updated_at",
                )
            },
        ),
    ]
    formfield_overrides = {
        models.JSONField: {"widget": JSONEditorWidget},
    }


@admin.register(OrderDeliveryMethod)
class OrderDeliveryMethodAdmin(admin.ModelAdmin):
    list_display = (
        "delivery_method_description",
        "id",
        "delivery_method_code",
        "partner",
        "status",
    )
    search_fields = (
        "id",
        "delivery_method_code",
        "delivery_method_description",
        "partner__name",
    )
    list_filter = ("status",)
    readonly_fields = (
        "id",
        "created_at",
        "updated_at",
    )
    fieldsets = [
        (
            _("Order delivery method information"),
            {
                "fields": (
                    "delivery_method_code",
                    "delivery_method_description",
                    "partner",
                )
            },
        ),
        (
            _("Status Information"),
            {
                "fields": ("status",),
            },
        ),
        (
            _("Source Information"),
            {
                "fields": (
                    "external_id",
                    "source",
                    "json_data",
                ),
            },
        ),
        (
            _("Timestamps"),
            {
                "fields": (
                    "created_at",
                    "updated_at",
                )
            },
        ),
    ]
    formfield_overrides = {
        models.JSONField: {"widget": JSONEditorWidget},
    }


@admin.register(Order)
class OrderAdmin(admin.ModelAdmin):
    list_display = (
        "increment_id",
        "id",
        "partner",
        "customer",
        "order_status",
        "created_at",
        "payment_code",
        "grand_total",
        "status",
    )
    search_fields = (
        "id",
        "payment_code",
        "partner__name",
        "order_status__status_code",
        "created_at",
        "increment_id",
        "customer__email",
    )
    list_filter = (
        "partner",
        "payment_code",
        "order_status",
        "status",
    )
    ordering = ("created_at",)
    readonly_fields = (
        "id",
        "increment_id",
        "created_at",
        "updated_at",
        "payment_code",
        "discount_amount",
        "weight",
        "subtotal",
        "tax_amount",
        "shipping_amount",
        "grand_total",
        "total_paid",
    )

    fieldsets = [
        (
            _("Order information"),
            {
                "fields": (
                    "increment_id",
                    "partner",
                    "customer",
                    "order_status",
                    "payment_code",
                    "delivery_method",
                    "weight",
                )
            },
        ),
        (
            _("Disccount Information"),
            {
                "fields": (
                    "coupon_code",
                    "discount_amount",
                ),
            },
        ),
        (
            _("Total Information"),
            {
                "fields": (
                    "subtotal",
                    "tax_amount",
                    "shipping_amount",
                    "grand_total",
                    "total_paid",
                ),
            },
        ),
        (
            _("Status Information"),
            {
                "fields": ("status",),
            },
        ),
        (
            _("Source Information"),
            {
                "fields": (
                    "external_id",
                    "source",
                    "json_data",
                ),
            },
        ),
        (
            _("Timestamps"),
            {
                "fields": (
                    "created_at",
                    "updated_at",
                )
            },
        ),
    ]

    inlines = [
        OrderProductInline,
        OrderAdressInline,
        OrderPaymentHistoryInline,
        OrderStatusHistoryInline,
    ]

    formfield_overrides = {
        models.JSONField: {"widget": JSONEditorWidget},
    }


@admin.register(OrderProduct)
class OrderProductAdmin(admin.ModelAdmin):
    list_display = (
        "id",
        "order",
        "product",
        "quantity",
        "base_amount",
        "total",
        "status",
        "created_at",
    )
    search_fields = (
        "id",
        "order__increment_id",
        "product__name",
        "quantity",
        "base_amount",
        "total",
    )
    list_filter = ("status",)
    ordering = ("order",)
    readonly_fields = (
        "id",
        "created_at",
        "updated_at",
    )

    fieldsets = [
        (
            _("Order product information"),
            {
                "fields": (
                    "order",
                    "product",
                    "quantity",
                    "base_amount",
                    "total",
                )
            },
        ),
        (
            _("Status Information"),
            {
                "fields": ("status",),
            },
        ),
        (
            _("Source Information"),
            {
                "fields": (
                    "external_id",
                    "source",
                    "json_data",
                ),
            },
        ),
        (
            _("Timestamps"),
            {
                "fields": (
                    "created_at",
                    "updated_at",
                )
            },
        ),
    ]

    formfield_overrides = {
        models.JSONField: {"widget": JSONEditorWidget},
    }


@admin.register(OrderStatusHistory)
class OrderStatusHistoryAdmin(admin.ModelAdmin):
    list_display = (
        "order",
        "id",
        "order_status",
        "created_at",
    )
    search_fields = (
        "id",
        "order__increment_id",
        "order_status__status_code",
        "comment",
    )
    list_filter = (
        "order_status",
        "status",
    )
    ordering = ("order",)
    readonly_fields = (
        "id",
        "created_at",
        "updated_at",
    )

    fieldsets = [
        (
            _("Order status history information"),
            {
                "fields": (
                    "order",
                    "order_status",
                    "comment",
                )
            },
        ),
        (
            _("Status Information"),
            {
                "fields": ("status",),
            },
        ),
        (
            _("Source Information"),
            {
                "fields": (
                    "external_id",
                    "source",
                    "json_data",
                ),
            },
        ),
        (
            _("Timestamps"),
            {
                "fields": (
                    "created_at",
                    "updated_at",
                )
            },
        ),
    ]

    formfield_overrides = {
        models.JSONField: {"widget": JSONEditorWidget},
    }


@admin.register(OrderPaymentHistory)
class OrderPaymentHistoryAdmin(admin.ModelAdmin):
    list_display = (
        "order",
        "id",
        "payment_code",
        "created_at",
        "status",
    )
    search_fields = (
        "id",
        "order__increment_id",
        "payment_code",
        "order__partner__name",
    )
    list_filter = (
        "order",
        "payment_code",
        "created_at",
    )
    ordering = ("order",)
    readonly_fields = (
        "id",
        "created_at",
        "updated_at",
    )

    fieldsets = [
        (
            _("Order payment history information"),
            {
                "fields": (
                    "order",
                    "payment_code",
                )
            },
        ),
        (
            _("Status Information"),
            {
                "fields": ("status",),
            },
        ),
        (
            _("Source Information"),
            {
                "fields": (
                    "external_id",
                    "source",
                    "json_data",
                ),
            },
        ),
        (
            _("Timestamps"),
            {
                "fields": (
                    "created_at",
                    "updated_at",
                )
            },
        ),
    ]

    formfield_overrides = {
        models.JSONField: {"widget": JSONEditorWidget},
    }


@admin.register(OrderAdress)
class OrderAdressAdmin(admin.ModelAdmin):
    list_display = (
        "order",
        "id",
        "address_type",
        "city",
        "phone",
        "created_at",
        "status",
    )
    search_fields = (
        "id",
        "order__increment_id",
        "address_type",
        "city__name",
        "address",
        "phone",
    )
    list_filter = (
        "address_type",
        "status",
    )
    ordering = ("order",)
    readonly_fields = (
        "id",
        "created_at",
        "updated_at",
    )
    fieldsets = [
        (
            _("Order address information"),
            {
                "fields": (
                    "order",
                    "address_type",
                    "city",
                    "phone",
                    "address",
                    "firstname",
                    "lastname",
                    "email",
                )
            },
        ),
        (
            _("Status Information"),
            {
                "fields": ("status",),
            },
        ),
        (
            _("Source Information"),
            {
                "fields": (
                    "external_id",
                    "source",
                    "json_data",
                ),
            },
        ),
        (
            _("Timestamps"),
            {
                "fields": (
                    "created_at",
                    "updated_at",
                )
            },
        ),
    ]
    formfield_overrides = {
        models.JSONField: {"widget": JSONEditorWidget},
    }



from django.core.management.base import BaseCommand

from artd_order.data.order_status import ORDER_STATUSES as STATUSES
from artd_order.models import OrderStatus


class Command(BaseCommand):
    help = "Create order statuses"

    def handle(self, *args, **kwargs):
        for status in STATUSES:
            if OrderStatus.objects.filter(id=status[0]).count() == 0:
                OrderStatus.objects.create(
                    id=status[0],
                    status_code=status[1],
                    status_description=status[2],
                )
                self.stdout.write(self.style.SUCCESS(f"{status[2]} was created"))
            else:
                status_obj = OrderStatus.objects.get(
                    id=status[0],
                )
                status_obj.status_code = status[1]
                status_obj.status_description = status[2]
                status_obj.save()
                self.stdout.write(self.style.WARNING(f"{status[2]} was updated"))



from django.db import models
from artd_customer.models import Customer
from artd_product.models import Product
from artd_partner.models import Partner
from artd_promotion.models import Coupon
from django.utils.translation import gettext_lazy as _
from django.db.models.signals import post_save, pre_save
from django.dispatch import receiver
from artd_location.models import City


ADDRESS_TYPE = (
    ("billing", _("Billing")),
    ("shipping", _("Shipping")),
)


class OrderBaseModel(models.Model):
    created_at = models.DateTimeField(
        _("Created at"),
        help_text=_("Date time on which the object was created."),
        auto_now_add=True,
        editable=False,
    )
    updated_at = models.DateTimeField(
        _("Updated at"),
        help_text=_("Date time on which the object was last updated."),
        auto_now=True,
        editable=False,
    )
    status = models.BooleanField(
        _("Status"),
        help_text=_("Status of the object."),
        default=True,
    )
    source = models.CharField(
        _("Source"),
        help_text=_("Source of the object."),
        max_length=100,
        null=True,
        blank=True,
    )
    external_id = models.CharField(
        _("External ID"),
        help_text=_("External ID of the object."),
        max_length=100,
        null=True,
        blank=True,
    )
    json_data = models.JSONField(
        _("JSON data"),
        help_text=_("JSON data"),
        null=True,
        blank=True,
        default=dict,
    )

    class Meta:
        abstract = True


class OrderDeliveryMethod(OrderBaseModel):
    """Model definition for Order Delivery Method."""

    partner = models.ForeignKey(
        Partner,
        verbose_name=_("Partner"),
        help_text=_("Partner"),
        on_delete=models.CASCADE,
    )
    delivery_method_code = models.CharField(
        _("Delivery method code"),
        help_text=_("Delivery method code"),
        max_length=100,
        unique=True,
    )
    delivery_method_description = models.CharField(
        _("Delivery method description"),
        help_text=_("Delivery method description"),
        max_length=250,
    )

    class Meta:
        """Meta definition for Order Delivery Method."""

        verbose_name = _("Order Delivery Method")
        verbose_name_plural = _("Order Delivery Methods")

    def __str__(self):
        """Unicode representation of Order Delivery Method."""
        return f"{self.delivery_method_description}"


class OrderStatus(OrderBaseModel):
    """Model definition for OrderStatus."""

    status_code = models.CharField(
        _("Order status code"),
        help_text=_("Order status code"),
        max_length=100,
        unique=True,
    )
    status_description = models.CharField(
        _("Order status description"),
        help_text=_("Order status description"),
        max_length=250,
    )

    class Meta:
        """Meta definition for OrderStatus."""

        verbose_name = _("Order Status")
        verbose_name_plural = _("Order Statuses")

    def __str__(self):
        """Unicode representation of OrderStatus."""
        return str(self.status_description)


class Order(OrderBaseModel):
    """Model definition for Order."""

    partner = models.ForeignKey(
        Partner,
        verbose_name=_("Partner"),
        help_text=_("Partner"),
        on_delete=models.CASCADE,
    )
    increment_id = models.PositiveBigIntegerField(
        _("Increment ID"),
        help_text=_("Increment ID"),
    )
    customer = models.ForeignKey(
        Customer,
        verbose_name=_("Customer"),
        help_text=_("Customer"),
        on_delete=models.CASCADE,
    )
    order_status = models.ForeignKey(
        OrderStatus,
        verbose_name=_("Order status"),
        help_text=_("Order status"),
        on_delete=models.CASCADE,
        default=0,
    )
    payment_code = models.CharField(
        _("Payment code"),
        help_text=_("Payment code"),
        max_length=100,
    )
    delivery_method = models.ForeignKey(
        OrderDeliveryMethod,
        verbose_name=_("Delivery method"),
        help_text=_("Delivery method"),
        on_delete=models.CASCADE,
    )
    coupon_code = models.ForeignKey(
        Coupon,
        verbose_name=_("Coupon code"),
        help_text=_("Coupon code"),
        on_delete=models.CASCADE,
        null=True,
        blank=True,
    )
    discount_amount = models.DecimalField(
        _("Base discount amount"),
        help_text=_("Base discount amount"),
        default=0.00,
        max_digits=20,
        decimal_places=2,
    )
    grand_total = models.DecimalField(
        _("Base grand total"),
        help_text=_("Base grand total"),
        default=0.00,
        max_digits=20,
        decimal_places=2,
    )
    shipping_amount = models.DecimalField(
        _("Base shipping amount"),
        help_text=_("Base shipping amount"),
        default=0.00,
        max_digits=20,
        decimal_places=2,
    )
    subtotal = models.DecimalField(
        _("Base subtotal"),
        help_text=_("Base subtotal"),
        default=0.00,
        max_digits=20,
        decimal_places=2,
    )
    tax_amount = models.DecimalField(
        _("Base tax amount"),
        help_text=_("Base tax amount"),
        default=0.00,
        max_digits=20,
        decimal_places=2,
    )
    total_paid = models.DecimalField(
        _("Base total paid"),
        help_text=_("Base total paid"),
        default=0.00,
        max_digits=20,
        decimal_places=2,
    )
    weight = models.DecimalField(
        _("Weight"),
        help_text=_("Weight"),
        default=0.00,
        max_digits=20,
        decimal_places=2,
    )
    comment = models.TextField(
        _("Comment"),
        help_text=_("Comment"),
        null=True,
        blank=True,
    )

    class Meta:
        """Meta definition for Order."""

        verbose_name = _("Order")
        verbose_name_plural = _("Orders")

    def __str__(self):
        """Unicode representation of Order."""
        return f"{self.partner} {self.increment_id}"

    @property
    def partner_increment_id(self):
        return f"{self.partner.name} {self.increment_id}"


class OrderProduct(OrderBaseModel):
    """Model definition for Order Product."""

    order = models.ForeignKey(
        Order,
        verbose_name=_("Order"),
        help_text=_("Order"),
        on_delete=models.CASCADE,
    )
    product = models.ForeignKey(
        Product,
        verbose_name=_("Product"),
        help_text=_("Product"),
        on_delete=models.CASCADE,
    )
    quantity = models.IntegerField(
        _("Quantity"),
        help_text=_("Quantity"),
        default=1,
    )
    base_amount = models.DecimalField(
        _("Base amount"),
        help_text=_("Base amount"),
        default=0.00,
        max_digits=20,
        decimal_places=2,
    )
    base_discount_amount = models.DecimalField(
        _("Base discount amount"),
        help_text=_("Base discount amount"),
        default=0.00,
        max_digits=20,
        decimal_places=2,
    )
    base_tax_amount = models.DecimalField(
        _("Base tax amount"),
        help_text=_("Base tax amount"),
        default=0.00,
        max_digits=20,
        decimal_places=2,
    )
    base_total = models.DecimalField(
        _("Base total"),
        help_text=_("Base total"),
        default=0.00,
        max_digits=20,
        decimal_places=2,
    )
    amount = models.DecimalField(
        _("Amount"),
        help_text=_("Amount"),
        default=0.00,
        max_digits=20,
        decimal_places=2,
    )
    discount_amount = models.DecimalField(
        _("Discount amount"),
        help_text=_("Discount amount"),
        default=0.00,
        max_digits=20,
        decimal_places=2,
    )
    tax_amount = models.DecimalField(
        _("Tax amount"),
        help_text=_("Tax amount"),
        default=0.00,
        max_digits=20,
        decimal_places=2,
    )
    total = models.DecimalField(
        _("Total"),
        help_text=_("Total"),
        default=0.00,
        max_digits=20,
        decimal_places=2,
    )

    class Meta:
        """Meta definition for Order Product."""

        verbose_name = _("Order Product")
        verbose_name_plural = _("Order Products")

    def __str__(self):
        """Unicode representation of Order Product."""
        return str(self.product.name)


class OrderStatusHistory(OrderBaseModel):
    """Model definition for Order Status History."""

    order_status = models.ForeignKey(
        OrderStatus,
        verbose_name=_("Order status"),
        help_text=_("Order status"),
        on_delete=models.CASCADE,
    )
    order = models.ForeignKey(
        Order,
        verbose_name=_("Order"),
        help_text=_("Order"),
        on_delete=models.DO_NOTHING,
    )
    comment = models.TextField(
        _("Comment"),
        help_text=_("Comment"),
        null=True,
        blank=True,
    )

    class Meta:
        """Meta definition for Order Status History."""

        verbose_name = _("Order Status History")
        verbose_name_plural = _("Order Status Histories")

    def __str__(self):
        """Unicode representation of Order Status History."""
        return str(self.order.increment_id)


class OrderPaymentHistory(OrderBaseModel):
    """Model definition for Order Payment History."""

    order = models.ForeignKey(
        Order,
        verbose_name=_("Order"),
        help_text=_("Order"),
        on_delete=models.CASCADE,
    )
    payment_code = models.CharField(
        _("Payment code"),
        help_text=_("Payment code"),
        max_length=100,
    )

    class Meta:
        """Meta definition for Order Payment History."""

        verbose_name = _("Order Payment History")
        verbose_name_plural = _("Order Payment Histories")

    def __str__(self):
        """Unicode representation of Order Payment History."""
        return str(self.id)


class OrderAdress(OrderBaseModel):
    """Model definition for Order Adress."""

    order = models.ForeignKey(
        Order,
        verbose_name=_("Order"),
        help_text=_("Order"),
        on_delete=models.CASCADE,
    )
    address_type = models.CharField(
        _("Address type"),
        help_text=_("Address type"),
        max_length=100,
        choices=ADDRESS_TYPE,
    )
    city = models.ForeignKey(
        City,
        verbose_name=_("City"),
        help_text=_("City"),
        on_delete=models.CASCADE,
    )
    address = models.CharField(
        _("Address"),
        help_text=_("Address"),
        max_length=250,
    )
    phone = models.CharField(
        _("Phone"),
        help_text=_("Phone"),
        max_length=100,
    )
    firstname = models.CharField(
        _("Firstname"),
        help_text=_("Firstname"),
        max_length=250,
        blank=True,
        null=True,
    )
    lastname = models.CharField(
        _("Lastname"),
        help_text=_("Lastname"),
        max_length=250,
        blank=True,
        null=True,
    )
    email = models.EmailField(
        _("Email"),
        help_text=_("Email"),
        max_length=250,
        blank=True,
        null=True,
    )

    class Meta:
        """Meta definition for Order Adress."""

        verbose_name = _("Order Adress")
        verbose_name_plural = _("Order Adresses")

    def __str__(self):
        """Unicode representation of Order Adress."""
        return f"{self.order.increment_id} ({self.address_type})"


@receiver(post_save, sender=Order)
def createfirst_status_history(sender, instance, created, **kwargs):
    if created:
        OrderStatusHistory.objects.create(
            order_status=instance.order_status,
            order=instance,
            comment="Order created",
        )


@receiver(pre_save, sender=Order)
def set_increment_id(sender, instance, **kwargs):
    # Verifica si es una nueva instancia (no tiene un ID asignado)
    if instance.pk is None:
        # Obtiene el último increment_id para el partner y lo incrementa en uno
        last_order = (
            Order.objects.filter(partner=instance.partner)
            .order_by("-increment_id")
            .first()
        )
        if last_order:
            instance.increment_id = last_order.increment_id + 1
        else:
            # Si es el primer Order para el Partner, establece el increment_id en 1
            instance.increment_id = 1
